Index: gscam/src/gscam.cpp
===================================================================
--- gscam/src/gscam.cpp	(revision 822)
+++ gscam/src/gscam.cpp	(working copy)
@@ -24,14 +24,27 @@
 int width, height;
 unsigned char *buffer = NULL;
 sensor_msgs::CameraInfo camera_info;
+std::string camera_parameters_file;
 
 int main(int argc, char** argv) {
-	char *config = getenv("GSCAM_CONFIG");
-	if (config == NULL) {
-		std::cout << "Problem getting GSCAM_CONFIG variable." << std::endl;
+	ros::init(argc, argv, "gscam_publisher");
+	ros::NodeHandle nh;
+
+
+	const char *config = getenv("GSCAM_CONFIG");
+    std::string gsconfig;
+
+    if (config != NULL) {
+        std::cout << "Using the GSCAM_CONFIG environment variable: " << config << std::endl;
+    } else if (nh.getParam("gscam/gsconfig", gsconfig) ) {
+        config = gsconfig.c_str();
+    } else {
+		std::cout << "Define the gstreamer configuration using the GSCAM_CONFIG variable or the gscam/gsconfig parameter." << std::endl;
 		exit(-1);
 	}
 
+    std::cout << "Gstreamer configuration: " << config << std::endl;
+
 	gst_init(0,0);
 	std::cout << "Gstreamer Version: " << gst_version_string() << std::endl;
 
@@ -62,19 +75,38 @@
 		std::cout << "stream is PAUSED." << std::endl;
 	}
 
+    
+
+    std::string frame_id;
+
+    if (! nh.getParam("gscam/frame_id", frame_id) ) {
+        frame_id = "/gscam";
+    }
+    
+    std::cout << "Using \"" << frame_id << "\" as the frame_id for this camera." << std::endl;
+
+    if (! nh.getParam("gscam/camera_parameters_file", camera_parameters_file) ) {
+        camera_parameters_file = "camera_parameters.txt";
+    }
+    
+    std::cout << "Using \"" << camera_parameters_file << "\" for the camera parameters." << std::endl;
+
+
 	// We could probably do something with the camera name, check
 	// errors or something, but at the moment, we don't care.
 	std::string camera_name;
-	if (camera_calibration_parsers::readCalibrationIni("../camera_parameters.txt", camera_name, camera_info)) {
+	if (camera_calibration_parsers::readCalibrationIni(camera_parameters_file.c_str(), camera_name, camera_info)) {
 	  ROS_INFO("Successfully read camera calibration.  Rerun camera calibrator if it is incorrect.");
 	}
 	else {
 	  ROS_ERROR("No camera_parameters.txt file found.  Use default file if no other is available.");
 	}
 
-	ros::init(argc, argv, "gscam_publisher");
-	ros::NodeHandle nh;
 
+
+
+
+
 	int preroll;
 	nh.param("brown/gscam/preroll", preroll, 0);
 	if (preroll) {
@@ -117,7 +149,12 @@
 		if (!rosPad) continue;
 		rosPad = false;
 
+        ros::Time now = ros::Time::now();
+
 		sensor_msgs::Image msg;
+        msg.header.frame_id = frame_id;
+        msg.header.stamp.sec = now.sec;
+        msg.header.stamp.nsec = now.nsec;
 		msg.width = width;
 		msg.height = height;
 		msg.encoding = "rgb8";
@@ -126,6 +163,9 @@
 		msg.data.resize(width*height*3);
 		std::copy(buffer, buffer+(width*height*3), msg.data.begin());
 
+        camera_info.header.stamp.sec = now.sec;
+        camera_info.header.stamp.nsec = now.nsec;
+
 		pub.publish(msg, camera_info);
 
 		ros::spinOnce();
@@ -165,12 +205,12 @@
   ROS_INFO("New camera info received");
   camera_info = req.camera_info;
 
-  if (camera_calibration_parsers::writeCalibrationIni("../camera_parameters.txt", "gscam", camera_info)) {
-    ROS_INFO("Camera information written to camera_parameters.txt");
+  if (camera_calibration_parsers::writeCalibrationIni(camera_parameters_file.c_str(), "gscam", camera_info)) {
+    ROS_INFO("Camera information written to the camera parameters file");
     return true;
   }
   else {
-    ROS_ERROR("Could not write camera_parameters.txt");
+    ROS_ERROR("Could not write the camera parameters file");
     return false;
   }
 }
